@@ -3,6 +3,11 @@
 
 calcPercentile <- function(mydata, pollutant = "o3", period = "month", percentile = 50,
                             data.thresh = 0, start = NA) {
+    site <- FALSE
+    if ("site" %in% names(mydata)) {
+        site <- TRUE
+        site.name <- mydata$site[1]
+    }
 
     make.percentile <- function(mydata, pollutant = "o3", period = "month", percentile = 50,
                                 data.thresh = 0, start = NA) {
@@ -23,5 +28,7 @@ calcPercentile <- function(mydata, pollutant = "o3", period = "month", percentil
     mydata <- lapply(percentile, function(x) make.percentile(mydata, pollutant = pollutant,
                                                                period = period, percentile = x))
     mydata <- Reduce(function(x, y, by = 'date') merge(x, y, by = 'date', all = TRUE), mydata)
+
+    if (site) mydata$site <- site.name
     mydata
 }
