@@ -11,7 +11,12 @@
 timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
                         statistic = "mean", percentile = NA, start.date = NA) {
     
+    ## extract variables of interest
+    vars <- names(mydata)
 
+    mydata <- checkPrep(mydata, vars, type = "default")
+  
+    
     if (!is.na(percentile)) {
         percentile <- percentile / 100
         if (percentile < 0 | percentile > 100) stop("Percentile range outside 0-100")
@@ -32,16 +37,24 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
     newMax <- function(x) {if (all(is.na(x))) return(NA) else max(x, na.rm = TRUE)}
 
     calc.mean <- function(mydata, start.date) { ## function to calculate means
-
+        
         ## pad out missing data
         mydata <- date.pad(mydata)
 
         ## start from a particular time, if given
         if (!is.na(start.date)) {
-            firstLine <- data.frame(date = as.POSIXct(start.date, "GMT"))
+               
+            firstLine <- data.frame(date = as.POSIXct(start.date))
             mydata <- rbind.fill(firstLine, mydata)
-        }
 
+            ## for cutting data must ensure it is in GMT because combining
+            ## data frames when system is not GMT puts it in local time!...
+            ## and then cut makes a string/factor levels with tz lost...
+            TZ <- format(mydata$date, "%Z")[1]
+            mydata$date <- as.POSIXct(format(mydata$date), tz = TZ) 
+     
+        }
+       
         if ("wd" %in% names(mydata)) {
             if (is.numeric(mydata$wd)) {
                 mydata$u <- sin(2 * pi * mydata$wd / 360)
@@ -49,9 +62,11 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
             }
         }
 
+       
         ## cut into sections dependent on period
         mydata$cuts <- cut(mydata$date, avg.time)
         
+        
         if (data.thresh > 0) {
 
             ## two methods of calculating stats, one that takes account of data capture (slow), the
@@ -90,8 +105,10 @@ timeAverage <- function(mydata, avg.time = "day", data.thresh = 0,
             dailymet$date <- as.Date(dailymet$date)
             
         } else {
-
-            dailymet$date <- as.POSIXct(dailymet$date, "GMT")
+            ## return the same TZ that we started with
+            TZ <- format(mydata$date, "%Z")[1]
+            dailymet$date <- as.POSIXct(format(dailymet$date), tz = TZ)                            
+           
         }
 
         if ("wd" %in% names(mydata)) {
